#!/usr/bin/python3
""" Utility classes and functions """

from time import strftime, gmtime
from flask import render_template, request
from mpbc import info
import boto3
import subprocess as sp


class Recording:
    """
    Simple class for Recording
    """

    def __init__(self):
        """
        """
        self.webcams = 0
        self.microphones = 0

        devices = sp.Popen('lsusb', stdout=sp.PIPE).communicate()[0]
        for device in devices.rstrip().decode().split('\n'):
            if 'C920' in device:
                self.webcams += 1
            elif 'C-Media Electronics' in device:
                self.microphones += 1


    def start(self):
        """
        Starts a recording process
        """
        sp.Popen(['supervisorctl', 'start', 'record'], stdout=sp.PIPE)


    def status(self):
        """
        Returns the status of the recording process
        """
        child = sp.Popen(['supervisorctl', 'status', 'record'], stdout=sp.PIPE)
        status = child.communicate()[0].decode().split()[1]
        return status


    def stop(self):
        """
        Stops the recording process
        """
        sp.Popen(['kill', self.get_pid()], stdout=sp.PIPE)
        sp.Popen(['supervisorctl', 'stop', 'record'], stdout=sp.PIPE)


    def encrypt(self):
        """
        Packages and encrypts the resultant media files
        """
        sp.Popen(['supervisorctl', 'start', 'encrypt'], stdout=sp.PIPE)


    def get_pid(self):
        """
        Gets and returns ffmpeg pid
        """
        child = sp.Popen(['pidof', 'ffmpeg'], stdout=sp.PIPE)
        return child.communicate()[0].strip()


class PIN:
    """
    Class for storing and checking user PINs
    """

    def __init__(self, pin):
        """
        """
        self.correct_pin = False
        self.attempt_counter = 5
        self.entered_pin = None
        self.pin = pin #change to import pin from file


    def check_pin(self, entered_pin):
        """
        Checks if the entered pin is the correct pin
        """
        self.entered_pin = entered_pin
        if self.attempt_counter == 0:
            return False
        if entered_pin == self.pin:
            self.correct_pin = True
        return self.correct_pin



def get_network_ssids():
    """
    Gets the network SSIDs
    """
    ssids = []
    child = sp.Popen(['iwlist', 'wlan0', 'scan'], stdout=sp.PIPE)
    for line in child.communicate()[0].decode().splitlines():    
        if line.strip().startswith('ESSID'):
            ssid = line.split('"')[1]
            if ssid != 'OutOfService':
                ssids.append(ssid)
    return ssids
        

def generate_wpa_supplicant(ssid, psk):
    """
    Generates a wpa_supplicant.conf file with the passed ssid and psk
    """
    print(ssid, psk)
    
    #Assures the password is greater than 8 characters    
    if len(psk) > 8:
        child = sp.Popen(['wpa_passphrase', ssid, psk], stdout=sp.PIPE)
        with open('/etc/wpa_supplicant/wpa_supplicant.conf', 'a') as wpa:
            for line in child.communicate()[0].decode().splitlines():
                if line.strip().startswith('#'):
                   continue
                wpa.write(line)
    

def get_curtime():
    return strftime("%Y%m%d-%H%M%S", gmtime())


def connect_wifi():
    pass
